{===================================================================================================

  Comming Library

       Canvas, c TRect.

====================================================================================================

  :

  17.08.2009 [*] DrawCellTextOut:      .
  18.06.2008 [*] .
  09.10.2003 [+] .
  31.08.2001 [+] DrawCheckRect.
  09.06.2001 [+] TextInRect, WrapTextInRect (  SoGraph).
             [+] VertCenter, HorCenter (  SoGraph).
  17.05.2001 [+]   BevelLine.
             [*]       .
  09.09.1998 [!]  Comming Library.

====================================================================================================
  Copyright 19982009 TSK Developer Laboratory, Moscow.                     Konstantin Tsvetkov
                                                                              e-mail: dev@tsklab.ru
                                                                              http://www.tsklab.ru
  CVS: $Id: CommingDisplay.pas,v 1.1 2012/02/23 06:37:52 tsk Exp $
===================================================================================================}
unit CommingDisplay;

interface

  uses Windows, SysUtils, Classes, Controls, Graphics, ExtCtrls,
      // Comming:
      CommingColor;

  {    Canvas    ,   ''    }
  procedure DrawCellTextOut( Canvas: TCanvas; const Rect: TRect; var Left: Integer; Text: String );
  procedure BevelLine( Cn: TCanvas; Cntl: TGraphicControl; Shape: TBevelShape; Style: TBevelStyle = bsLowered );
  procedure DrawCheckRect( Canvas: TCanvas; CheckboxRect: TRect; Enabled, Checked: Boolean );
  {    Rect  API }
  procedure TextInRect(Canvas: TCanvas; const Text: string; Rect: TRect; TextAlign: TAlignment);
  {    Rect  API   }
  procedure WrapTextInRect(Canvas: TCanvas; const Text: string; Rect: TRect; TextAlign: TAlignment);
  {    Height   Rect. 
     "",     ,     
     Rect }
  function  VertCenter(Rect: TRect; Height: Integer): Integer;
  {    Width   Rect. 
     "x",     ,     
     Rect }
  function  HorCenter(Rect: TRect; Width: Integer): Integer;
  procedure RepaintFlatBorder( Handle: HWND );

implementation

uses Types;
//==================================================================================================
procedure DrawCellTextOut( Canvas: TCanvas; const Rect: TRect; var Left: Integer; Text: String );
begin
  with Canvas do begin
    if ( Length( Trim( Text )) > 0 )
                          and (( Rect.Right - Rect.Left - Left ) > ( TextWidth('') + 1)) then begin
      while (( TextWidth( Text ) + 1 ) > ( Rect.Right - Rect.Left - Left ))
        do Text := Copy( Text, 1, Length( Text ) - 2) + '';
      TextOut( Rect.Left + Left, Rect.Top + 1, Text );
      Inc( Left, TextWidth( Text ) + 1);
    end;
  end;
end;
//==================================================================================================
procedure BevelLine( Cn: TCanvas; Cntl: TGraphicControl; Shape: TBevelShape; Style: TBevelStyle );
  var Color1, Color2: TColor;

  procedure DrawLine( Cn: TCanvas; C: TColor; X1, Y1, X2, Y2: Integer);
  begin
    with Cn do begin
      Pen.Color := C;
      MoveTo(X1, Y1);
      LineTo(X2, Y2);
    end;
  end;

begin
  if Style = bsLowered then begin
    Color1 := clBtnShadow;
    Color2 := clBtnHighlight;
  end else begin
    Color1 := clBtnHighlight;
    Color2 := clBtnShadow;
  end;
  case Shape of
(*    bsBox: BevelRect(Rect(0, 0, Width - 1, Height - 1));
    bsFrame:
      begin
          Temp := Color1;
          Color1 := Color2;
          BevelRect(Rect(1, 1, Width - 1, Height - 1));
          Color2 := Temp;
          Color1 := Temp;
          BevelRect(Rect(0, 0, Width - 2, Height - 2));
        end;
    bsTopLine:
      begin
          BevelLine(Color1, 0, 0, Width, 0);
          BevelLine(Color2, 0, 1, Width, 1);
      end;*)
    bsBottomLine:
      begin
          DrawLine( Cn, Color1, 0, Cntl.Height - 2, Cntl.Width, Cntl.Height - 2 );
          DrawLine( Cn, Color2, 0, Cntl.Height - 1, Cntl.Width, Cntl.Height - 1 );
      end;
(*    bsLeftLine:
      begin
          BevelLine(Color1, 0, 0, 0, Height);
          BevelLine(Color2, 1, 0, 1, Height);
      end;
    bsRightLine:
        begin
          BevelLine(Color1, Width - 2, 0, Width - 2, Height);
          BevelLine(Color2, Width - 1, 0, Width - 1, Height);
        end;*)
  end;
end;
//==================================================================================================
function VertCenter(Rect: TRect; Height: Integer): Integer;
begin
  Result := Rect.Top + ( Rect.Bottom - Rect.Top - Height ) div 2;
end;
//==================================================================================================
function HorCenter(Rect: TRect; Width: Integer): Integer;
begin
  Result := Rect.Left + ( Rect.Right - Rect.Left - Width) div 2;
end;
//==================================================================================================
procedure TextInRect;
  const Aligns: array[TAlignment] of Word = (DT_LEFT, DT_RIGHT, DT_CENTER);
  var PText: array[0..256] of Char;
      Flags: Word;
      Leng : Integer;
begin
  Flags := Aligns[TextAlign];
  StrPCopy(PText, Text);
  Leng := Length(Text);
  DrawText(Canvas.Handle, PText, Leng, Rect, Flags);
end;
//==================================================================================================
procedure WrapTextInRect(Canvas: TCanvas; const Text: string; Rect: TRect; TextAlign: TAlignment);
  const Aligns: array[TAlignment] of Word = (DT_LEFT, DT_RIGHT, DT_CENTER);
  var PText: array[0..256] of Char;
      Flags: Word;
      Leng : Integer;
begin
  Flags := Aligns[TextAlign];
  StrPCopy(PText, Text);
  Leng := Length(Text);
  DrawText(Canvas.Handle, PText, Leng, Rect, Flags or DT_WORDBREAK);
end;
//==================================================================================================
procedure RepaintFlatBorder( Handle: HWND );
  var DC : HDC;
      aRect : TRect;
      BrushFrame: HBrush;
begin
  BrushFrame := CreateSolidBrush({clYellow} GetSysColor( COLOR_BTNFACE ) );
  DC := GetWindowDC( Handle );
  try
    GetWindowRect( Handle, aRect );
    OffsetRect( aRect, -aRect.Left, -aRect.Top );
    FrameRect( DC, aRect, BrushFrame);
    InflateRect(aRect, -1, -1);
    DrawEdge( DC, aRect, BDR_SUNKENOUTER, BF_RECT )
  finally
    ReleaseDC( Handle, DC);
    DeleteObject( BrushFrame );
  end;
end;
//==================================================================================================
procedure DrawCheckRect( Canvas: TCanvas; CheckboxRect: TRect; Enabled, Checked: Boolean );
  var D, S: Integer;
begin
  D := ( CheckboxRect.Bottom - CheckboxRect.Top - 2 ) div 5;
  S := ( CheckboxRect.Bottom - CheckboxRect.Top - 2 ) - D - D - D - D;
  with Canvas do begin
    Pen.Style  := psSolid;
    Pen.Width  := 1;
    if Enabled then begin
      Brush.Color := clDimWindow;
      Pen.Color   := clDimWindow;
    end else begin
      Brush.color := clBtnFace;
      Pen.color   := clBtnFace;
    end;
    if Checked then begin
      if Enabled then Pen.Color := clHighlight else Pen.Color := clBtnShadow;
      Polyline([ Point( CheckboxRect.Left  + 1 + D,     CheckboxRect.Top    + 1 + D + D ),
                 Point( CheckboxRect.Left  + 1 + D,     CheckboxRect.Top    + 1 + D + D + S ),
                 Point( CheckboxRect.Left  + 1 + D + D, CheckboxRect.Bottom - 1 - D ),
                 Point( CheckboxRect.Right - 1 - D,     CheckboxRect.Top    + 1 + D + S )
                 (*,
                 Point( CheckboxRect.Left  + 1 + D + D,     CheckboxRect.Bottom - 1 - D ),
                 Point( CheckboxRect.Left  + 1 + D + D + D + D, CheckboxRect.Bottom - 1 - D - D - D ),
                 Point( CheckboxRect.Left  + 1 + D + D, CheckboxRect.Top    + 1 + D + D + D ),
                 Point( CheckboxRect.Left  + 1 + D,     CheckboxRect.Top + 1 + D + D )*)

       ]);
(*      PenPos := Point( CheckboxRect.Left + 3, CheckboxRect.Top + 5 );
      LineTo( CheckboxRect.Left + 7, CheckboxRect.Top + 9 );
      PenPos := Point( CheckboxRect.Left + 3, CheckboxRect.Top + 6 );
      LineTo( CheckboxRect.Left + 6, CheckboxRect.Top + 9 );
      PenPos := Point( CheckboxRect.Left + 3, CheckboxRect.Top + 7 );
      LineTo( CheckboxRect.Left + 6, CheckboxRect.Top + 10 );
      PenPos := Point( CheckboxRect.Left + 9, CheckboxRect.Top + 3 );
      LineTo( CheckboxRect.Left + 5, CheckboxRect.Top + 7);
      PenPos := Point( CheckboxRect.Left + 9, CheckboxRect.Top + 4 );
      LineTo( CheckboxRect.Left + 5, CheckboxRect.Top + 8 );
      PenPos := Point( CheckboxRect.Left + 9, CheckboxRect.Top + 5);
      LineTo( CheckboxRect.Left + 6, CheckboxRect.Top + 8 );*)
    end;
    Brush.Color := clBtnShadow;
    FrameRect( CheckboxRect );
  end;
end;
//==================================================================================================
end.
