{===================================================================================================

  Comming Library.

       .

====================================================================================================

  :

  09.10.2009 [*] TakeFileSize:  .
  29.09.2009 [+] NormalFileName:   .
  28.05.2008 [*] GetVolumeSerialNumber:     .
  22.05.2008 [+] GetVolumeSerialNumber:   .
  25.09.2007 [+] ExtractFilePathFormat:      .
  16.10.2006 [+] ExtractFilePathNameNoExt:     ,   .
  26.05.2006 [+] ZIPFile:    zip-.
  14.03.2005 [*] .
  28.11.2004 [*] ExtractFileNameNoExt:     .
  17.08.2004 [*] ReplaceFileLine:    ,   .
  16.08.2004 [+] ReplaceFileLine:    .
  11.09.2003 [*] TakeFileSize:    read-only .
  03.09.2003 [+] TakeFileSize:   .
  07.12.2002 [*] RecurseDir:  .
  31.07.2002 [*] GetDiskKind:  .
             [*] GetVolumeName:     .
  28.06.2002 [-] .
  04.06.2001 [+] GetVolumeName:   .
  10.05.2001 [+]  .
  09.09.1998 [!]  Comming Library.

====================================================================================================
  Copyright 19982009 TSK Developer Laboratory, Moscow.                     Konstantin Tsvetkov
                                                                              e-mail: dev@tsklab.ru
                                                                              http://www.tsklab.ru
  CVS: $Id: CommingFile.pas,v 1.1 2012/02/23 06:37:52 tsk Exp $
===================================================================================================}
unit CommingFile;

interface

  uses Windows, Classes, SysUtils, Forms, ShellAPI, CommingString;

  //     ()  :
  function    GetVolumeNo( Drive: String ): Integer;
  //     ()  :
  function    GetVolumeSerialNumber( Drive: String ): String;
  //    ():
  function    GetVolumeName( Drive: Char ): String;
  //    ():
  function    GetVolumeLetter( Name: String ): String;
  //   :
  function    GetDiskKind( Drive: Char ): Integer;
  //   :
  function    TakeFileSize( FileName: String ): Int64;
  //     :
  function    ExtractFileNameNoExt( FileName: String ): String;
  function    ExtractFileDirectory( FileName: String ): String;
  //     ,     :
  function    ExtractFilePathNameNoExt( FileName: String ): String;
  function    ExtractFilePathFormat( FileName: String ): String;
  //      :
  procedure   RecurseDir( PathInicial, Ext: String; var FileList: TStringList );
  //   '/'   ,  :
  function    NormalDir( const DirName: String ): String;
  //   :
  function    NormalFileName( FileName: String ): String;
  //    :
  procedure   ReplaceFileLine( FileName, SepBeg, SepEnd: String; Data: TStringList;
                               FileBlank: String = '' );
  //   pkzip25.
  procedure   ZIPFile( FileName: String );

resourcestring
  erNotSeparator = '  %s   %s';
  erNotFileBlank = '  %s   %s';
  erNotPath      = '  %s    ';

implementation
//==================================================================================================
function  GetVolumeNo( Drive: String ): Integer;
  var V: Array[0..11] of Char;
      S: Array[0..5] of Char;
      N: DWord;
      M, I: DWORD;
begin
  Drive := Drive + ':\';
  GetVolumeInformation( PChar( Drive ), @V, MAX_PATH, @N, M, I, @S, 5 );
  Result := N;
end;
//==================================================================================================
function GetVolumeSerialNumber( Drive: String ): String;
  var n: Integer;
begin
  n := GetVolumeNo( Drive );
  Result := IntToHex( HiWord( n ), 4 ) + '-' + IntToHex( LoWord( n ), 4 )
end;
//==================================================================================================
function GetVolumeName( Drive: Char ): String;
  var S: Array[0..5] of Char;
      N: DWord;
      M, I: DWORD;
begin
  SetLength( Result, MAX_PATH );
  GetVolumeInformation( PChar( Drive + ':\' ), PChar( Result ), MAX_PATH, @N, M, I, @S, 5 );
  SetLength (Result, StrLen ( PChar( Result )));
end;
//==================================================================================================
function GetVolumeLetter( Name: String ): String;
  var i: Integer;
begin
  Result := 'A';
  for i := 65 to 90 do
    if UpperCase( GetVolumeName( Char(i) )) = UpperCase( Name ) then begin
      Result := Char( i );
      Break;
    end;
end;
//==================================================================================================
function GetDiskKind( Drive: Char ): Integer;
begin
  Result := GetDriveType( PChar( Drive + ':\' ));
end;
//==================================================================================================
function TakeFileSize( FileName: String ): Int64;
//var  SFile: File;
begin
  with TFileStream.Create( FileName, fmOpenRead or fmShareDenyWrite) do
    try
      Result := Size;
    finally
      Free;
    end;
{  AssignFile( SFile, FileName );
  FileMode := 0;
  Reset( SFile, 1 );
  try
    Result := FileSize( SFile );
  finally
    CloseFile( SFile );
  end;}
end;
//==================================================================================================
function ExtractFileNameNoExt( FileName: String ):String;
begin
  FileName := ExtractFileName( FileName );
  Result := Copy( ExtractFileName( FileName ), 1, Length( FileName ) - Length( ExtractFileExt( FileName )));
end;
//==================================================================================================
function ExtractFileDirectory( FileName: String ): String;
begin
  Result := ExtractFileDir( FileName );
  if ( Length( Result ) >= 2 ) and ( Result[2] = ':' )
    then Result := Copy( Result, 3, Length( Result ) )
end;
//==================================================================================================
function ExtractFilePathNameNoExt( FileName: String ): String;
begin
  Result := ExtractFileDir( FileName ) + '\' + ExtractFileNameNoExt( FileName );
end;
//==================================================================================================
function ExtractFilePathFormat( FileName: String ): String;
begin
  Result := ExtractFileDir( FileName ) + '\%s.' + ExtractFileExt( FileName );
end;
//==================================================================================================
procedure RecurseDir( PathInicial, Ext: String; var FileList: TStringList );
  var SearchRec: TSearchRec;
      Result: Integer;
begin
  Result := FindFirst( PathInicial + '*.*', faAnyFile, SearchRec);
  while Result = 0 do begin
    if SearchRec.Name[1] <> '.' then begin
      //  :
      if ( SearchRec.Attr and faDirectory ) > 0 then begin
        //  :
        RecurseDir( PathInicial + SearchRec.Name + '\', Ext, FileList )
      end else begin
        if ( UpperCase( ExtractFileExt( SearchRec.Name )) = '.' + UpperCase( Ext ))
          then FileList.Add( PathInicial + SearchRec.Name );
      end;
    end;
    Application.ProcessMessages;
    Result := FindNext( SearchRec );
  end;
  FindClose( SearchRec );
end;
//==================================================================================================
function NormalDir( const DirName: String): String;
begin
  Result := DirName;
  if Result = EmptyStr then exit;
  if Result[ Length( Result )] <> '\' then Result := Result + '\';
end;
//==================================================================================================
function NormalFileName( FileName: String ): String;
begin
  Result := DeleteChars( FileName, '\/*:');
end;
//==================================================================================================
procedure ReplaceFileLine( FileName, SepBeg, SepEnd: String; Data: TStringList; FileBlank: String );
  var Fil, Tmp: TStringList;
      i, j: Integer;
      Ins: Boolean;
begin
  Fil := TStringList.Create;
  Tmp := TStringList.Create;
  if FileExists( FileName )
    then Fil.LoadFromFile( FileName )
    else if FileExists( FileBlank )
           then Fil.LoadFromFile( FileBlank )
           else raise EAbort.CreateFmt( erNotFileBlank, [ FileName, FileBlank ]);
  Ins := False;
  for i := 0 to Fil.Count - 1  do begin
    if ( Pos( SepBeg, Fil[i] ) > 0 ) then begin
      Tmp.Add( Fil[i] );
      for j := 0 to Data.Count - 1 do Tmp.Add( Data[j] );
      Ins := True;
    end else if ( Pos( SepEnd, Fil[i] ) > 0 ) then begin
      Tmp.Add( Fil[i] );
      Ins := False
    end else if not Ins then Tmp.Add( Fil [i] )
  end;
  if Ins then raise EAbort.CreateFmt( erNotSeparator, [ FileName, SepEnd ]);
  if not ForceDirectories( ExtractFilePath( FileName ))
    then raise EAbort.CreateFmt( erNotPath, [ FileName ]);
  Tmp.SaveToFile( FileName );
  Tmp.Free;
  Fil.Free;
end;
//==================================================================================================
procedure ZIPFile( FileName: String );
  var sZIP: String;
begin
  sZIP := ChangeFileExt( FileName, '.zip');
  ShellExecute( Application.Handle, 'open', 'pkzip25',
                PChar( Format( ' -add -move "%s" "%s"', [ sZIP, FileName ])),
                nil, SW_SHOWNORMAL );
end;
//==================================================================================================
end.
